# pylint: disable=missing-function-docstring
# pylint: disable=unused-import
# pylint: disable=line-too-long
'''
    A module of utility methods used for generating random information
    or just doing shit randomly with strings.

    ----------

    Meta
    ----------
    `author`: Colemen Atwood
    `created`: 06-03-2022 10:18:27
    `memberOf`: random
    `version`: 1.0
    `method_name`: random
'''

from utils.random_utils import text,phone,email,url,abstract_name,rand












